==> thelounge-2.1.0.tgz: package/CONTRIBUTING.md <==
## Contributing

Welcome to The Lounge, it's great to have you here! We thank you in advance for
your contributions.

### I have a question

- Find us on the Freenode channel `#thelounge`. You might not get an answer
  right away, but this channel is full of nice people who will be happy to
  help you.

### I want to report a bug

- Look at the [open and closed
  issues](https://github.com/thelounge/lounge/issues?q=is%3Aissue) to see if
  this was not already discussed before. If you can't see any, feel free to
  [open a new issue](https://github.com/thelounge/lounge/issues/new).

### I want to contribute to the code

- Make sure to discuss your ideas with the community in an
  [issue](https://github.com/thelounge/lounge/issues) or on the IRC channel.
- Take a look at the open issues labeled as [`help wanted`](https://github.com/thelounge/lounge/issues?q=is%3Aopen+is%3Aissue+label%3Abug+label%3A%22help+wanted%22)
  if you want to help without having a specific idea in mind.
- Make sure that your PRs do not contain unnecessary commits or merge commits.
  [Squash commits](https://git-scm.com/book/en/v2/Git-Tools-Rewriting-History)
  whenever possible.
- [Rebase](https://git-scm.com/book/en/v2/Git-Branching-Rebasing) (instead of
  merge) outdated PRs on the `master` branch.
- Give extra care to your commit messages. Use the [imperative present
  tense](https://git-scm.com/book/ch5-2.html#Commit-Guidelines) and [follow Tim
  Pope's guidelines](http://tbaggery.com/2008/04/19/a-note-about-git-commit-messages.html).
- Each PR will be reviewed by at least two different project maintainers. You
  can read more about this in the [maintainers'
corner](https://github.com/thelounge/lounge/wiki/Maintainers'-corner).
- Please document any relevant changes in the documentation that can be found
  [in its own repository](https://github.com/thelounge/thelounge.github.io).

==> thelounge-2.6.0.tgz: package/CONTRIBUTING.md <==
## Contributing

Welcome to The Lounge, it's great to have you here! We thank you in advance for
your contributions.

### I want to report a bug

- Look at the [open and closed
  issues](https://github.com/thelounge/lounge/issues?q=is%3Aissue) to see if
  this was not already discussed before. If you can't see any, feel free to
  [open a new issue](https://github.com/thelounge/lounge/issues/new).

### I want to contribute to the code

- Make sure to discuss your ideas with the community in an
  [issue](https://github.com/thelounge/lounge/issues) or on the IRC channel.
- Take a look at the open issues labeled as [`up for grabs`](https://github.com/thelounge/lounge/issues?q=is%3Aopen%20is%3Aissue%20label%3A%22up%20for%20grabs%22)
  if you want to help without having a specific idea in mind.
- Make sure that your PRs do not contain unnecessary commits or merge commits.
  [Squash commits](https://git-scm.com/book/en/v2/Git-Tools-Rewriting-History)
  whenever possible.
- [Rebase](https://git-scm.com/book/en/v2/Git-Branching-Rebasing) (instead of
  merge) outdated PRs on the `master` branch.
- Give extra care to your commit messages. Use the [imperative present
  tense](https://git-scm.com/book/ch5-2.html#Commit-Guidelines) and [follow Tim
  Pope's guidelines](http://tbaggery.com/2008/04/19/a-note-about-git-commit-messages.html).
- Each PR will be reviewed by at least two different project maintainers. You
  can read more about this in the [maintainers'
corner](https://github.com/thelounge/lounge/wiki/Maintainers'-corner).
- Please document any relevant changes in the documentation that can be found
  [in its own repository](https://github.com/thelounge/thelounge.github.io).
